# -*- coding: utf-8 -*-
from setuphelpers import *
import os
import sys

if "__file__" in locals():
    sys.path.insert(0, os.path.dirname(os.path.realpath(__file__)))
    from setupdevhelpers import *

sources_dir_name = "sources"


def update_package():
    package_updated = False

    mkdirs(sources_dir_name)
    if dir_is_empty(sources_dir_name):
        # Asking for a dir_or_file
        dir_or_file = ask_message(
            control.package,
            "Do you want to import a directory as sources?\nClick No to import a file as sources.\nClick Cancel for more informations.",
            3 + 32,
            raise_error=False,
        )

        # Copying sources to package
        if dir_or_file == 6:
            source_src = ask_directory("Please select the source directory that will be copied in the package", raise_error=False)
            source_name = os.path.basename(source_src)
            source_dst = makepath(sources_dir_name, source_name)
            if isdir(source_dst):
                remove_tree(source_dst)
            copytree2(source_src, source_dst)
        elif dir_or_file == 7:
            source_src = ask_filename("Please select the source file that will be copied in the package", raise_error=False)
            source_name = os.path.basename(source_src).rsplit(".", 1)[0]
            source_dst = makepath(sources_dir_name, os.path.basename(source_src))
            if isfile(source_dst):
                remove_file(source_dst)
            filecopyto(source_src, source_dst)
        else:
            # error("Do you want to import a file or a directory?")
            ask_message(
                control.package,
                "You can place your sources manually by editing this package. When the package is ready, it is recommended to run update_package() again.",
                64,
            )
            error("Please edit this package.")
    else:
        source_name = list(set([os.path.basename(s) for s in glob.glob(makepath(sources_dir_name, "*"))]))[0]
        if isfile(source_name):
            source_name = source_name.rsplit(".", 1)[0]

    # control.installed_size
    control.installed_size = get_size(sources_dir_name)
    control.save_control_to_wapt()

    # Renaming package
    if "template" in control.package:
        complete_control_package(control, control.package.split("-", 1)[0] + "-" + source_name.lower() + "-sources")
        complete_control_name(control, source_name)
        if "template" in control.package:
            error("Please rename the package.")
        else:
            version = str(int(control.get_software_version()) + 1)
    else:
        version = str(int(control.get_software_version()))

    # Updating setup.py depends_package variable
    depends_package = ask_input("depends_package", "You can define depends_package if you want to remove sources when package is installed:")
    if depends_package:
        lines = []
        with open("setup.py", "r", encoding="utf8") as f:
            lines = f.readlines()
            for i in range(len(lines)):
                line = lines[i]
                if line.startswith("depends_package"):
                    line = 'depends_package = "%s"\n' % depends_package
                    lines[i] = line
                    break
        with open("setup.py", "w", encoding="utf8", newline="\n") as f:
            f.writelines(lines)

    # Changing version of the package
    if Version(version, 4) > Version(control.get_software_version(), 4):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Validating or not update-package-sources
    return package_updated
